import React from 'react';
import AuthContext from './AuthContext';
import { Container, Spinner, Alert, Row } from 'react-bootstrap';
import printMoney from './util';

class Dashboard extends React.Component {
    static contextType = AuthContext;

    constructor(props) {
        super(props);
        this.state = {
            name: null,
            balance: null,
            isLoading: false,
            error: null
        };
    }

    componentDidMount() {
        this.setState({ isLoading: true });

        fetch('/api/member/'+this.context.num.toString(),
              { headers: { 'x-authentication': this.context.token }})
            .then(response => {
                if (!response.ok) {
                    throw new Error(response.status.toString()+' '+response.statusText);
                }
                return response.json();
            })
            .then(member => this.setState({ balance: member.balance, name: member.name, isLoading: false }))
            .catch(e => this.setState({ error: e.message, isLoading: false }));
    }

    render() {
        if (this.state.isLoading) {
            return (
              <Row className="justify-content-md-center">
                <Spinner animation="border" />
              </Row>
            );
        }

        if (this.state.error != null) {
            return (
                <Alert variant="danger">
                   Ha ocurrido un error cargando tu saldo: {this.state.error}
                </Alert>
            );
        }

        return (
            <Container>
                <h1>{this.state.name}</h1>
                <p>Saldo: {printMoney(this.state.balance)}</p>
            </Container>
        );
    }
}

export default Dashboard;
