import React from 'react';
import { Table, Spinner, Alert, Row } from 'react-bootstrap';
import AuthContext from './AuthContext';
import printMoney from './util';

class ProductList extends React.Component {
    static contextType = AuthContext;

    constructor(props) {
        super(props);
        this.state = {
            products: [],
            isLoading: false,
            error: null
        };
    }

    componentDidMount() {
        this.setState({ isLoading: true });

        fetch('/api/product', { headers: { 'x-authentication': this.context.token }})
            .then(response => {
                if (!response.ok) {
                    throw new Error(response.status.toString()+' '+response.statusText);
                }
                return response.json();
            })
            .then(products => this.setState({ products, isLoading: false }))
            .catch(e => this.setState({ error: e.message, isLoading: false }));
    }

    render() {
        if (this.state.isLoading) {
            return (
              <Row className="justify-content-md-center">
                <Spinner animation="border" />
              </Row>
            );
        }

        if (this.state.error != null) {
            console.log(this.state.error);
            return (
                <Alert variant="danger">
                   Ha ocurrido un error cargando el listado de productos: {this.state.error}
                </Alert>
            );
        }

        const entries = this.state.products.map((product) => {
            return (
                <tr key={product.code}>
                    <td>{product.code}</td>
                    <td>{product.name}</td>
                    <td>{printMoney(product.price)}</td>
                    <td>{product.stock}</td>
                </tr>
            )
        });

        return (
            <Table striped bordered hover>
                <thead>
                    <tr>
                        <th>codigo</th>
                        <th>Nombre</th>
                        <th>Precio</th>
                        <th>Existencias</th>
                    </tr>
                </thead>
                <tbody>
                    {entries}
                </tbody>
            </Table>
        );
    }
}

export default ProductList;
