import React from 'react';
import { Table, Spinner, Alert, Row } from 'react-bootstrap';
import AuthContext from './AuthContext';
import printMoney from './util';

class MemberList extends React.Component {
    static contextType = AuthContext;

    constructor(props) {
        super(props);
        this.state = {
            members: [],
            isLoading: false,
            error: null
        };
    }

    componentDidMount() {
        this.setState({ isLoading: true });

        fetch('/api/member', { headers: { 'x-authentication': this.context.token }})
            .then(response => {
                if (!response.ok) {
                    throw new Error(response.status.toString()+' '+response.statusText);
                }
                return response.json();
            })
            .then(members => this.setState({ members, isLoading: false }))
            .catch(e => this.setState({ error: e.message, isLoading: false }));
    }

    render() {
        if (this.state.isLoading) {
            return (
              <Row className="justify-content-md-center">
                <Spinner animation="border" />
              </Row>
            );
        }

        if (this.state.error != null) {
            console.log(this.state.error);
            return (
                <Alert variant="danger">
                   Ha ocurrido un error cargando el listado de socias: {this.state.error}
                </Alert>
            );
        }

        const entries = this.state.members.map((member) => {
            return (
                <tr key={member.num}>
                    <td>{member.num}</td>
                    <td>{member.name}</td>
                    <td>{member.email}</td>
                    <td>{printMoney(member.balance)}</td>
                </tr>
            )
        });

        return (
            <Table striped bordered hover>
                <thead>
                    <tr>
                        <th>Numero</th>
                        <th>Nombre</th>
                        <th>Email</th>
                        <th>Saldo</th>
                    </tr>
                </thead>
                <tbody>
                    {entries}
                </tbody>
            </Table>
        );
    }
}

export default MemberList;
